@@ -1,4 +1,5 @@
 import toml
+import pathlib
 
 
 def load_config(file_name: str, config='default') -> dict:
@@ -14,7 +15,8 @@ def load_config(file_name: str, config='default') -> dict:
     Returns:
         dict: {'token': 'xxxx', 'url': 'xxxx'} 
     """
-    with open(file_name) as f:
+    p_rel = pathlib.Path(file_name)
+    with open(p_rel) as f:
         toml_setting_file = toml.load(f)
     if config not in toml_setting_file:
         raise TypeError(
